==> nukleus-oauth-0.61-sources.jar: org/reaktivity/nukleus/oauth/internal/types/HttpHeaderFW.java <==
// TODO: license
package org.reaktivity.nukleus.oauth.internal.types;

import java.nio.charset.StandardCharsets;
import org.agrona.DirectBuffer;
import org.agrona.MutableDirectBuffer;

public final class HttpHeaderFW extends Flyweight {
  public static final int FIELD_OFFSET_NAME = 0;

  public static final int FIELD_OFFSET_VALUE = 0;

  private final String8FW nameRO = new String8FW();

  private final String16FW valueRO = new String16FW();

  public String8FW name() {
    return nameRO;
  }

  public String16FW value() {
    return valueRO;
  }

  @Override
  public HttpHeaderFW wrap(DirectBuffer buffer, int offset, int maxLimit) {
    super.wrap(buffer, offset, maxLimit);
    nameRO.wrap(buffer, offset + FIELD_OFFSET_NAME, maxLimit);
    valueRO.wrap(buffer, nameRO.limit() + FIELD_OFFSET_VALUE, maxLimit);
    checkLimit(limit(), maxLimit);
    return this;
  }

  @Override
  public HttpHeaderFW tryWrap(DirectBuffer buffer, int offset, int maxLimit) {
    if (null == super.tryWrap(buffer, offset, maxLimit)) {
      return null;
    }
    if (null == nameRO.tryWrap(buffer, offset + FIELD_OFFSET_NAME, maxLimit)) {
      return null;
    }
    if (null == valueRO.tryWrap(buffer, nameRO.limit() + FIELD_OFFSET_VALUE, maxLimit)) {
      return null;
    }
    if (limit() > maxLimit) {
      return null;
    }
    return this;
  }

  @Override
  public int limit() {
    return valueRO.limit();
  }

  @Override
  public String toString() {
    return String.format("HTTP_HEADER [name=%s, value=%s]", nameRO.asString(), valueRO.asString());
  }

  public static final class Builder extends Flyweight.Builder<HttpHeaderFW> {
    private static final int INDEX_NAME = 0;

    private static final int INDEX_VALUE = 1;

    private static final int FIELD_COUNT = 2;

    private final String8FW.Builder nameRW = new String8FW.Builder();

    private final String16FW.Builder valueRW = new String16FW.Builder();

    private int lastFieldSet = -1;

    public Builder() {
      super(new HttpHeaderFW());
    }

    private String8FW.Builder name() {
      assert lastFieldSet == INDEX_NAME - 1;
      return nameRW.wrap(buffer(), limit(), maxLimit());
    }

    public Builder name(String value) {
      String8FW.Builder nameRW = name();
      nameRW.set(value, StandardCharsets.UTF_8);
      lastFieldSet = INDEX_NAME;
      limit(nameRW.build().limit());
      return this;
    }

    public Builder name(String8FW value) {
      String8FW.Builder nameRW = name();
      nameRW.set(value);
      lastFieldSet = INDEX_NAME;
      limit(nameRW.build().limit());
      return this;
    }

    public Builder name(DirectBuffer buffer, int offset, int length) {
      String8FW.Builder nameRW = name();
      nameRW.set(buffer, offset, length);
      lastFieldSet = INDEX_NAME;
      limit(nameRW.build().limit());
      return this;
    }

    private String16FW.Builder value() {
      assert lastFieldSet == INDEX_VALUE - 1;
      return valueRW.wrap(buffer(), limit(), maxLimit());
    }

    public Builder value(String value) {
      String16FW.Builder valueRW = value();
      valueRW.set(value, StandardCharsets.UTF_8);
      lastFieldSet = INDEX_VALUE;
      limit(valueRW.build().limit());
      return this;
    }

    public Builder value(String16FW value) {
      String16FW.Builder valueRW = value();
      valueRW.set(value);
      lastFieldSet = INDEX_VALUE;
      limit(valueRW.build().limit());
      return this;
    }

    public Builder value(DirectBuffer buffer, int offset, int length) {
      String16FW.Builder valueRW = value();
      valueRW.set(buffer, offset, length);
      lastFieldSet = INDEX_VALUE;
      limit(valueRW.build().limit());
      return this;
    }

    @Override
    public Builder wrap(MutableDirectBuffer buffer, int offset, int maxLimit) {
      super.wrap(buffer, offset, maxLimit);
      lastFieldSet = -1;
      limit(offset);
      return this;
    }

    @Override
    public Builder wrap(ArrayFW.Builder<? extends ArrayFW<HttpHeaderFW>, ? extends Flyweight.Builder<HttpHeaderFW>, HttpHeaderFW> array) {
      super.wrap(array);
      lastFieldSet = -1;
      return this;
    }

    @Override
    public Builder rewrap() {
      super.rewrap();
      return this;
    }

    @Override
    public HttpHeaderFW build() {
      assert lastFieldSet == FIELD_COUNT - 1;
      lastFieldSet = -1;
      return super.build();
    }
  }
}

==> nukleus-oauth-0.66-sources.jar: org/reaktivity/nukleus/oauth/internal/types/HttpHeaderFW.java <==
// TODO: license
package org.reaktivity.nukleus.oauth.internal.types;

import java.nio.charset.StandardCharsets;
import org.agrona.DirectBuffer;
import org.agrona.MutableDirectBuffer;

public final class HttpHeaderFW extends Flyweight {
  public static final int FIELD_OFFSET_NAME = 0;

  public static final int FIELD_OFFSET_VALUE = 0;

  private final String8FW nameRO = new String8FW();

  private final String16FW valueRO = new String16FW();

  public String8FW name() {
    return nameRO;
  }

  public String16FW value() {
    return valueRO;
  }

  @Override
  public HttpHeaderFW wrap(DirectBuffer buffer, int offset, int maxLimit) {
    super.wrap(buffer, offset, maxLimit);
    nameRO.wrap(buffer, offset + FIELD_OFFSET_NAME, maxLimit);
    valueRO.wrap(buffer, nameRO.limit() + FIELD_OFFSET_VALUE, maxLimit);
    checkLimit(limit(), maxLimit);
    return this;
  }

  @Override
  public HttpHeaderFW tryWrap(DirectBuffer buffer, int offset, int maxLimit) {
    if (null == super.tryWrap(buffer, offset, maxLimit)) {
      return null;
    }
    if (null == nameRO.tryWrap(buffer, offset + FIELD_OFFSET_NAME, maxLimit)) {
      return null;
    }
    if (null == valueRO.tryWrap(buffer, nameRO.limit() + FIELD_OFFSET_VALUE, maxLimit)) {
      return null;
    }
    if (limit() > maxLimit) {
      return null;
    }
    return this;
  }

  @Override
  public int limit() {
    return valueRO.limit();
  }

  @Override
  public String toString() {
    return String.format("HTTP_HEADER [name=%s, value=%s]", nameRO.asString(), valueRO.asString());
  }

  public static final class Builder extends Flyweight.Builder<HttpHeaderFW> {
    private static final int INDEX_NAME = 0;

    private static final int INDEX_VALUE = 1;

    private static final int FIELD_COUNT = 2;

    private final String8FW.Builder nameRW = new String8FW.Builder();

    private final String16FW.Builder valueRW = new String16FW.Builder();

    private int lastFieldSet = -1;

    public Builder() {
      super(new HttpHeaderFW());
    }

    private String8FW.Builder name() {
      assert lastFieldSet == INDEX_NAME - 1;
      return nameRW.wrap(buffer(), limit(), maxLimit());
    }

    public Builder name(String value) {
      String8FW.Builder nameRW = name();
      nameRW.set(value, StandardCharsets.UTF_8);
      lastFieldSet = INDEX_NAME;
      limit(nameRW.build().limit());
      return this;
    }

    public Builder name(String8FW value) {
      String8FW.Builder nameRW = name();
      nameRW.set(value);
      lastFieldSet = INDEX_NAME;
      limit(nameRW.build().limit());
      return this;
    }

    public Builder name(DirectBuffer buffer, int offset, int length) {
      String8FW.Builder nameRW = name();
      nameRW.set(buffer, offset, length);
      lastFieldSet = INDEX_NAME;
      limit(nameRW.build().limit());
      return this;
    }

    private String16FW.Builder value() {
      assert lastFieldSet == INDEX_VALUE - 1;
      return valueRW.wrap(buffer(), limit(), maxLimit());
    }

    public Builder value(String value) {
      String16FW.Builder valueRW = value();
      valueRW.set(value, StandardCharsets.UTF_8);
      lastFieldSet = INDEX_VALUE;
      limit(valueRW.build().limit());
      return this;
    }

    public Builder value(String16FW value) {
      String16FW.Builder valueRW = value();
      valueRW.set(value);
      lastFieldSet = INDEX_VALUE;
      limit(valueRW.build().limit());
      return this;
    }

    public Builder value(DirectBuffer buffer, int offset, int length) {
      String16FW.Builder valueRW = value();
      valueRW.set(buffer, offset, length);
      lastFieldSet = INDEX_VALUE;
      limit(valueRW.build().limit());
      return this;
    }

    @Override
    public Builder wrap(MutableDirectBuffer buffer, int offset, int maxLimit) {
      super.wrap(buffer, offset, maxLimit);
      lastFieldSet = -1;
      limit(offset);
      return this;
    }

    @Override
    public Builder wrap(ArrayFW.Builder<?, ?, ?> array) {
      super.wrap(array);
      lastFieldSet = -1;
      return this;
    }

    @Override
    public Builder rewrap() {
      super.rewrap();
      return this;
    }

    @Override
    public HttpHeaderFW build() {
      assert lastFieldSet == FIELD_COUNT - 1;
      lastFieldSet = -1;
      return super.build();
    }
  }
}
